@@ -5,7 +5,7 @@
  * 
  * application arguments processor
  * 
- * Copyright (C) 2007, 2008 Lukas Jelinek, <lukas@aiken.cz>
+ * Copyright (C) 2007, 2008, 2012 Lukas Jelinek, <lukas@aiken.cz>
  * 
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of one of the following licenses:
@@ -17,9 +17,13 @@
  * If you want to help with choosing the best license for you,
  * please visit http://www.gnu.org/licenses/license-list.html.
  * 
+ * Credits:
+ *   Christian Ruppert (new include to build with GCC 4.4+)
+ * 
  */
 
 
+#include <cstdio>
 #include <cstring>
 
 #include "strtok.h"
