@@ -5,7 +5,7 @@
  *
  * inotify cron system
  *
- * Copyright (C) 2006, 2007, 2008 Lukas Jelinek, <lukas@aiken.cz>
+ * Copyright (C) 2006, 2007, 2008, 2012 Lukas Jelinek, <lukas@aiken.cz>
  *
  * This program is free software; you can use it, redistribute
  * it and/or modify it under the terms of the GNU General Public
@@ -14,6 +14,7 @@
  * Credits:
  *   David Santinoli (supplementary groups)
  *   Boris Lechner (spaces in event-related file names)
+ *   Christian Ruppert (new include to build with GCC 4.4+)
  *
  */
 
@@ -26,6 +27,7 @@
 #include <grp.h>
 #include <stdlib.h>
 #include <sys/stat.h>
+#include <cstdio>
 #include <cstring>
 
 #include "usertable.h"
